#
# spec file for package ghc-recursion-schemes
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name recursion-schemes
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.2.2.5
Release:        bp156.1.1
Summary:        Representing common recursion patterns as higher-order functions
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-cabal-doctest-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-fix-devel
BuildRequires:  ghc-free-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
%endif

%description
Many recursive functions share the same structure, e.g. pattern-match on the
input and, depending on the data constructor, either recur on a smaller input
or terminate the recursion with the base case. Another one: start with a seed
value, use it to produce the first element of an infinite list, and recur on a
modified seed in order to produce the rest of the list. Such a structure is
called a recursion scheme. Using higher-order functions to implement those
recursion schemes makes your code clearer, faster, and safer. See README for
details.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown docs

%changelog
* Sun Oct 15 2023 Peter Simons <psimons@suse.com>
- Update recursion-schemes to version 5.2.2.5.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/recursion-schemes-5.2.2.5/src/CHANGELOG.markdown
* Mon Nov  1 2021 psimons@suse.com
- Update recursion-schemes to version 5.2.2.2.
  [#]# 5.2.2.2
  * Support GHC-9.0 and GHC-9.2
* Mon Mar 22 2021 psimons@suse.com
- Update recursion-schemes to version 5.2.2.1.
  [#]# 5.2.2.1
  * Fix build issue regarding `Setup.hs`. See #120.
* Sun Feb 21 2021 psimons@suse.com
- Update recursion-schemes to version 5.2.2.
  [#]# 5.2.2
  * More Mendler-style recursion-schemes: `mpara`, `mzygo`, `mana`, `mapo`, and
    `mfutu`.
  * `makeBaseFunctor` no longer generates warnings when combined with
    DerivingStrategies.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct 20 2020 psimons@suse.com
- Add recursion-schemes at version 5.2.1.
